This package is provided to manage the C++ extension module that provides
Python bindings for the GROMACS molecular simulation software suite.

This package owns the ``gromacs`` entry point group.
See https://packaging.python.org/specifications/entry-points/

See https://github.com/kassonlab/gromacs-gmxapi for more project information.

This project is migrating to the GROMACS master branch. The GROMACS 2020 release
should become the authoritative base for this package.
